import java.applet.Applet;
import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Frame;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import quadbase.reportdesigner.ReportAPI.DBInfo;
import quadbase.reportdesigner.ReportAPI.QbReport;
import quadbase.reportdesigner.ReportElements.SubReportObject;
import quadbase.reportdesigner.ReportViewer.Viewer;
import quadbase.reportdesigner.util.ColInfo;

public class SubReport extends Applet {
	static final long serialVersionUID = 1;

	public static void main(java.lang.String[] args) {

		try {

			SubReport doReport = new SubReport();
			Frame frame = new Frame();
			frame.setLayout(new BorderLayout());
			frame.add("Center", doReport.doSubReport(frame));
			frame.setSize(900, 800);
			frame.addWindowListener(new WindowAdapter() {
				@Override
				public void windowClosing(WindowEvent e) {
					System.exit(0);
				}
			});
			frame.setVisible(true);

		} catch (Exception ex) {

			ex.printStackTrace();

		}

	}

	@Override
	public void init() {

		setLayout(new BorderLayout());
		add("Center", doSubReport(this));

	}

	Component doSubReport(Object parent) {
		QbReport.setEspressManagerUsed(false);

		//		Begin Code : Creating the root Report
		DBInfo rootInfo = new DBInfo("jdbc:hsqldb:woodview",
				"org.hsqldb.jdbcDriver",
				"sa",
				"",
				"SELECT Orders.OrderID, Products.ProductName, " +
						"Products.UnitPrice, Order_Details.Stain, " +
						"Order_Details.StainColor, Order_Details.Quantity " +
						"FROM Order_Details, Products, Orders " +
						"WHERE ((Order_Details.OrderID = Orders.OrderID) " +
						"AND (Products.ProductID = Order_Details.ProductID)) " +
						"AND ((Orders.OrderDate BETWEEN '2003-01-10' AND '2003-31-12'));");

		ColInfo rootColInfo[] = new ColInfo[6];
		rootColInfo[0] = new ColInfo(0);
		rootColInfo[0].setRowBreak(true);
		rootColInfo[1] = new ColInfo(1);
		rootColInfo[2] = new ColInfo(2);
		rootColInfo[3] = new ColInfo(3);
		rootColInfo[4] = new ColInfo(4);
		rootColInfo[5] = new ColInfo(5);

		QbReport rootReport = new QbReport(
				parent,
				QbReport.SUMMARY,
				rootInfo,
				rootColInfo,
				"SubReport.rpt");
		//		End Code : Creating the root Report

		//		Begin Code : Creating the sub report
		DBInfo subReportInfo = new DBInfo(
				"jdbc:hsqldb:woodview",
				"org.hsqldb.jdbcDriver",
				"sa",
				"",
				"SELECT Employees.FirstName + ' ' + Employees.LastName AS Employee, "
						+
						"Count(Order_Details.OrderID) AS Orders, "
						+
						"Sum( ( Products.UnitPrice + Order_Details.StainCost )  * Order_Details.Quantity) AS Sales "
						+
						"FROM Employees, Products, Orders, Order_Details " +
						"WHERE ((Orders.EmployeeID = Employees.EmployeeID) " +
						"AND (Orders.OrderID = Order_Details.OrderID) " +
						"AND (Products.ProductID = Order_Details.ProductID)) " +
						"AND (((Orders.OrderDate BETWEEN '2003-01-10' AND '2003-31-12'))) " +
						"GROUP BY Employees.FirstName + ' ' + Employees.LastName;");

		ColInfo subReportColInfo[] = new ColInfo[3];
		for (int i = 0; i < subReportColInfo.length; i++) {
			subReportColInfo[i] = new ColInfo(i);
		}

		try {
			//			createSubReport(root report, report type, sub report data source, sub report column mapping, template)
			SubReportObject reportCell = quadbase.reportdesigner.ReportAPI.SubReport
					.createSubReport(
							rootReport,
							QbReport.COLUMNAR,
							subReportInfo,
							subReportColInfo,
							"SubReportSub.rpt");
			reportCell.setWidth(rootReport.getTable().getHeader().getWidth() - 2);
			reportCell.setHeight(2);
			//			Or use the following method if the height of the subreport may change 
			//			reportCell.setResizeToFitContent(true);

			reportCell.setY(0);
			reportCell.setX(2);

			//			Add SubReport to the Table Header
			rootReport.getTable().getHeader().addData(reportCell);
			rootReport.getTable().getHeader().setHeight(1.8);
		} catch (Exception ex) {
			ex.printStackTrace();
		}
		//		End Code : Creating the sub report

		return (new Viewer().getComponent(rootReport));

	}

}
